==> deepin-log-viewer_6.1.8.tar.xz: BUILD/translations/deepin-log-viewer_th.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="th">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html))</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Login record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Null</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.1.15.tar.xz: BUILD/translations/deepin-log-viewer_th.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="th">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clear log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 week</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 month</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>3 months</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Emergency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alert</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Debug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Event Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PID:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Action:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Login record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Debug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Emergency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alert</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Process</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Date and Time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Event Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Process:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PID:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
